@@ -1,10 +1,12 @@
 # -*- coding: utf-8 -*-
 """WSGI middleware initialization for the busmon application."""
 
+import tg
 from busmon.config.app_cfg import base_config
 from busmon.config.environment import load_environment
 
 from moksha.middleware import make_moksha_middleware
+from tw2.core import make_middleware as make_tw2_middleware
 
 __all__ = ['make_app']
 
@@ -34,7 +36,22 @@ def make_app(global_conf, full_stack=True, **app_conf):
 
     """
 
-    wrap_app = lambda app: make_moksha_middleware(app, app_conf)
+
+    if tg.__version__ < '2.1.0':
+        # Oh... epel.  :(
+        wrap_app = lambda app: make_tw2_middleware(
+            make_moksha_middleware(
+                app, app_conf,
+            ),
+            default_engine='mako',
+            res_prefix=tg.config.get(
+                'busmon.resource_path_prefix', '/busmon/resources/',
+            ),
+        )
+    else:
+        # On modern TG, tw2 is included.
+        wrap_app = lambda app: make_moksha_middleware(app, app_conf)
+
     app = make_base_app(
         global_conf, full_stack=True,
         wrap_app=wrap_app,
